<?php
/*
Plugin Name: Inactive User Deleter
Plugin URI: https://wordpress.org/plugins/inactive-user-deleter/
Version: 1.45
Requires at least: 3.1.0
Description: When your project lives so long, and website got a lot of fake user's registrations (usually made by spammers, bots, etc). This tool will help you to clean this mess up. You can filter, select and delete users.
Author: Korol Yuriy aka Shra <to@shra.ru>
Author URI: https://shra.ru
Donate link: https://www.paypal.me/YuriyKing
Tags: user, managment, users managment, delete, multy removal, pack deletion, user cleaner
License: GPLv2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html

*/
if (!class_exists('InactiveUserDeleter')) {
class InactiveUserDeleter
{
	const actual_version = 1.45;
	const status = 'production';
	var $ss2_active = null;

    public function __construct()
    {
		//Actions
		if (is_admin()) {
			mb_internal_encoding("UTF-8");
			mb_language('uni');

			add_action('admin_menu', array($this, 'menu'));
			add_filter('plugin_action_links', array($this, 'add_action_links'), 10, 2 );
		}

		//check for alarm message!
		add_action('init', array($this, 'init_hook'), 10);

		//store last login DTM
		add_action('wp_login', array($this, 'last_successful_authorization'));

		//to intercept confirmation codes
		add_action('login_form', array($this, 'login_form_hook'));

		add_action('wp_login', array($this, 'login_hook'), 10, 2);
	}

	/*
	* Last visit data
	*/
	public function last_successful_authorization($login) {
		global $user_ID;
		$name = get_userdatabylogin($login);
		update_usermeta($name->ID, 'last_login_gtm', time());
	}

	public function login_hook($user_login, $user ) {
		//remove confirmation timeout on log-in
		$time = get_user_meta($user->ID, '_IUD_deltime', true);
		if (!empty($time)) {
			delete_user_meta( $user->ID, '_IUD_deltime');
			update_user_meta( $user->ID, '_IUD_cancelcode', 'confirmed');
		}
	}

	public function login_form_hook() {
		if (!empty($_GET['iud-confirm'])) {
			$UID = $_GET['uid'] + 0;
			$code = get_user_meta($UID, '_IUD_cancelcode', true);

			if (empty($code)) return;
			if ($code == 'confirmed') {
				echo '<div style="padding: 20px; margin: 10px 0; font-weight: bold; background-color: #F0FFF0">'
				. __('Your confirmation code was already accepted.') . '</div>';
			} else
			if ($_GET['iud-confirm'] == $code) {
				delete_user_meta( $UID, '_IUD_deltime');
				update_user_meta( $UID, '_IUD_cancelcode', 'confirmed');
				echo '<div style="padding: 20px; margin: 10px 0; font-weight: bold; background-color: #F0FFF0">'
				. __('Your confirmation code is accepted. Thank you for your confirmation!') . '</div>';
			} else {
				echo '<div style="padding: 20px; margin: 10px 0; font-weight: bold; background-color: #FFF0F0">'
				. __('Incorrect confirmation code!') . '</div>';

			}
		}
	}

	public function init_hook() {
		$OP = self::read_settings();

		//inform about IU
		if (!empty($OP['informME']) && $OP['informPeriod'] > 0) {
			//it's time
			if (time() - $OP['last-inform'] >= $OP['informPeriod'] * 86400) {

				$number = 0;
				global $wpdb;

				//get inactive user by number posts - no comments, no posts
				$query = "SELECT COUNT(WC.comment_ID) as approved, WU.ID
					FROM {$wpdb->prefix}users WU
					LEFT JOIN {$wpdb->prefix}comments WC ON WC.user_id = WU.ID AND WC.comment_approved = 1
					WHERE
						(SELECT COUNT(*) FROM {$wpdb->prefix}posts PST
						 WHERE PST.post_author = WU.ID AND PST.post_status = 'publish'
						 AND NOT PST.post_type IN ('attachment', 'revision')) = 0
					GROUP BY WU.ID
					HAVING COUNT(WC.comment_ID) = 0 ";

				$number = count($wpdb->get_results($query));

				if ($number && $number >= $OP['informUsersNumber']) {
					wp_mail(
						get_option('admin_email'),
						$_SERVER['HTTP_HOST'] . ': ' . __('Inactive User Deleter Notification'),
						'<html>
<head profile="http://www.w3.org/1999/xhtml/vocab">
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
</head>
<body>
<p>Alarm, alarm!</p>
<p>It`s time to clean-up inactive users list on your website ' . $_SERVER['HTTP_HOST'] . '.</p>
<p>We have ' . $number. ' inactive user(s), who has no approved comments or published posts.</p>
<p>--<br />
Forever yours, Inactive User Deleter.</p>
</body>
</html>',
						array('Content-Type: text/html; charset=UTF-8')
					);
					$OP['last-inform'] = time();
					self::save_settings($OP);
				}

			}
		}

		//check deletion timeout
		$U = get_users(
			array(
				'meta_key' => '_IUD_deltime',
				'meta_value' => time(),
				'meta_compare' => '<',
			)
		);
		//delete users
		if (!empty($U)) {
			require_once(ABSPATH . 'wp-admin/includes/user.php');
			foreach ($U as $user) {
				if ($user->ID != 1)	wp_delete_user($user->ID);
      }
		}
	}

  /***
   * admin_menu action implementation
   **/
	public function menu() {
		add_users_page(__('Inactive users'), __('Inactive users'), 'delete_users', __FILE__, array($this, 'toolpage'));
	}

	public function toolpage() {
		global $wpdb, $user_ID;
		$this->ss2_active = is_plugin_active('subscribe2/subscribe2.php');

		readfile(dirname(__FILE__) . '/styles.css');
?>
<div class="wrap" id="IUD_area">
<h2><?php echo __('Inactive users deleter tool')?></h2>
<hr />
<p><?php echo __('When your project lives so long, site accumulates a lot of fake users (usually it is spammer\'s registrations). This tool will help you to clean this mess up')?>.</p>
<p><?php echo  __('You can do it manually (one by one) or automatically (be carefull with me, baby :))')?>.</p>

<nav id="IUD_pager">
	<div data-page="IUD_page_1"><?php echo  __('Find & Wipe')?></div>
	<div data-page="IUD_page_2" id="misc-button"><?php echo  __('Misc')?></div>
	<div data-page="IUD_page_3"><?php echo  __('About plugin')?></div>
</nav>

<div class="sub-page" id="IUD_page_1" >
<p><?php echo  __('Choose the criterias, then check the user\'s list that is will displayed. If this list will correct - hit the button &laquo;Kill them all&raquo;')?>.</p>

<form method="POST" action="#outputs" id="inactive-user-deleter-form">
<?php
	//output_filter_part
	$this->t_user_filter();

    if (!isset($_POST['op'])) $_POST['op'] = 'stand_by';

    switch ($_POST['op']) {
    case 'stand_by':
      //i like it
      break;
    case 'finally_delete':
    case 'delete':
      //delete all selected users
      echo '<hr />';
      if (empty($_POST['f_users'])) {
        echo __('I done all work. Really it was nothing to do. So I did nothing. :) You didn\'t select any user.');
      } else {
        if ( !current_user_can('delete_users') ) {
          __('You can&#8217;t delete users (no rights). Sorry.... :)');
        } else if ($_POST['op'] == 'finally_delete') {
				  $OP = self::read_settings();
				  $confirmPeriod = $_POST['confirmPeriod'] <= 0 ? 1 : $_POST['confirmPeriod'] + 0;

          echo __('Deleting...') . '<br />';
          $cnt_deleted = 0;
   				$cnt_sendmail = 0;
          foreach($_POST['f_users'] as $user_id_to_delete) {
            //real delete

            if ($user_id_to_delete == $user_ID) {
              echo __('I can\'t to delete your profile !') . '<br />';
              continue; //i never will delete current-user
            }

            if ($user_id_to_delete == 1) {
              echo __('I will never delete super-user !') . '<br />';
              continue; //i never will delete admin-user
            }

  					if (get_user_option('wp_user_level', $user_id_to_delete) >= 10) {
              echo __('I will never delete user with admin privileges !') . '<br />';
              continue; //i never will delete admin-user
  					}

				  	if (!empty($OP['informUsers'])) {
  						//check if user already has notification
  						$deltime = get_user_meta($user_id_to_delete, '_IUD_deltime', true);
  						if (!empty($deltime)) continue;
  						//check if user once confirmed before
  						$code = get_user_meta($user_id_to_delete, '_IUD_cancelcode', true);
  						if ($code == 'confirmed') continue;

  						//mark account for delete
  						update_user_meta( $user_id_to_delete, '_IUD_deltime', time() + $confirmPeriod * 86400);
  						$code = wp_generate_password();
  						update_user_meta( $user_id_to_delete, '_IUD_cancelcode', $code);

  						//send confirmation letter
  						$confirmURL = 'http://' . $_SERVER['HTTP_HOST'] . '/wp-login.php?iud-confirm=' . urlencode($code) . '&uid=' . $user_id_to_delete;
  						$mail = $wpdb->get_var("SELECT user_email FROM $wpdb->users WHERE ID = {$user_id_to_delete}");
  	 				  $mailbody = str_replace(
  							array(
  								':sitename',
  								':confirmPeriod',
  								':link'),
  							array(
  								$_SERVER['HTTP_HOST'],
  								$confirmPeriod,
  								'<a href="' . $confirmURL . '">' . $confirmURL . '</a>'),
  							$OP['confirmLetter']);

  						wp_mail($mail,
	 						  $_SERVER['HTTP_HOST'] . ': ' . __('confirm your account.'),
							 '<html><head profile="http://www.w3.org/1999/xhtml/vocab">
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" /></head>
<body>' . $mailbody . '</body></html>',
							 array('Content-Type: text/html; charset=UTF-8')
						  );
						  $cnt_sendmail ++;
  					} else {
	 					  wp_delete_user($user_id_to_delete);
						  $cnt_deleted ++;
					  }
          }

  				//output actions status
  				if ($cnt_deleted > 0) {
  					if ($cnt_deleted == 1)
  						echo $cnt_deleted . ' ' . __('user was deleted.');
  					else
  						echo $cnt_deleted . ' ' . __('users were deleted.');
  				}
  				else if ($cnt_sendmail > 0) {
  					if ($cnt_sendmail == 1)
  						echo $cnt_sendmail . ' ' . __('user was notified.');
  					else
  						echo $cnt_sendmail . ' ' . __('users were notified.');
  				} else {
  					echo __('No real action were undertaken.');
  				}

        } else {
          if (!is_array($_POST['f_users'])) $_POST['f_users'] = array($_POST['f_users']);
          echo '<span style="background-color: red; padding: 5px; color: white;">' . __('This is my last warning !') . '</span><br /><br />
              This is very serious, I will delete - ' . count($_POST['f_users']) . ' user(s). Data will be erased permanently and cannot be
              restored automatically.<br />Do you will proceed ?
              <input type="button" value="' . __('Yes') . '!" onclick="this.form.op.value=\'finally_delete\'; this.form.submit();"/>&nbsp;
              <input type="button" value="' . __('No, don\'t do it, please !') . '" onclick="this.form.submit();"/>';
        }
      }
    case 'search_users':
      //Ooohh damn, i hate to work!
		  $conditions = array();
		  $conditions_sec2 = array(1);

  		if (!empty($_POST['f_approve'])) {
  			//user with approved comments
  			if ($_POST['f_approve'] == 'yes') {
  				$conditions[] = "EXISTS (SELECT * FROM {$wpdb->prefix}comments WCAPP WHERE WCAPP.user_id = WU.ID AND WCAPP.comment_approved = 1)";
  			} else {
  				$conditions[] = "NOT EXISTS (SELECT * FROM {$wpdb->prefix}comments WCAPP WHERE WCAPP.user_id = WU.ID AND WCAPP.comment_approved = 1)";
  			}
  		}

  		if (!empty($_POST['has_spam'])) {
  			if ($_POST['has_spam'] === 'yes') {
  				$conditions[] = "EXISTS (SELECT * FROM {$wpdb->prefix}comments WCSPM WHERE WCSPM.user_id = WU.ID AND WCSPM.comment_approved = 'spam')";
  			} else {
  				$conditions[] = "NOT EXISTS (SELECT * FROM {$wpdb->prefix}comments WCSPM WHERE WCSPM.user_id = WU.ID AND WCSPM.comment_approved = 'spam')";
  			}
  		}

  		if (!empty($_POST['f_usereverlogin'])) {
  			if ($_POST['f_usereverlogin'] === 'yes') {
  				$conditions[] = "(WUM2.meta_value > 0 OR WUM21.meta_value > '1970-01-02 00:00:01')";
  			} else {
  				$conditions[] = "((WUM2.meta_value = 0 OR WUM2.meta_value IS NULL) AND (WUM21.meta_value is NULL OR WUM21.meta_value <= '1970-01-02 00:00:01'))";
  			}
  		}

      if (!empty($_POST['f_lastlogin'])) {
        $days = (int) $_POST['f_lastlogin'] + 0;
        $time = time() - $days * 86400;
        $timeStr = date('Y-m-d H:i:s', $time);
        $conditions[] = "(WUM2.meta_value < $time OR WUM21.meta_value < '$timeStr')";
      }

  		if (!empty($_POST['has_recs'])) {
  			if ($_POST['has_recs'] === 'yes') {
  				$conditions[] = "EXISTS (SELECT * FROM {$wpdb->prefix}posts WP WHERE WP.post_author = WU.ID
  					AND NOT WP.post_type in ('attachment', 'revision') AND WP.post_status = 'publish')";
  			} else {
  				//ignore user with posts
  				$conditions[] = "NOT EXISTS (SELECT * FROM {$wpdb->prefix}posts WP WHERE WP.post_author = WU.ID
  					AND NOT WP.post_type in ('attachment', 'revision') AND WP.post_status = 'publish')";
  			}
  		}

  		//section two
  		$days = empty($_POST['daysleft']) ? 0 : $_POST['daysleft'] + 0;
  		if ($days >= 0) {
  			$tmStr = date('Y-m-d H:i:s', time() - $days * 86400);
  			if (empty($_POST['f_daysleft'])) {
  				$conditions_sec2[] = "WU.user_registered >= '$tmStr'";
  			} else {
  				$conditions_sec2[] = "WU.user_registered < '$tmStr'";
  			}
  		}

  		if ($_POST['user_level'] != '') {
  			$ul = isset($_POST['user_level']) ?  $_POST['user_level'] + 0 : 0;
  			if ($_POST['user_level_eq'] == '>=') {
  				$conditions_sec2[] = "(WUM.meta_value >= $ul OR (WUM.meta_value IS NULL AND $ul <= 0))";
  			} else {
  				$conditions_sec2[] = "(WUM.meta_value <= $ul OR (WUM.meta_value IS NULL AND $ul >= 0))";
  			}
  		}

  		if ($this->ss2_active) {
  			if (!empty($_POST['has_SS2'])) {
  				$conditions_sec2[] = "EXISTS (SELECT * FROM {$wpdb->prefix}subscribe2 WSS2 WHERE WSS2.email = WU.user_email)";
  			} else {
  				$conditions_sec2[] = "NOT EXISTS (SELECT * FROM {$wpdb->prefix}subscribe2 WSS2 WHERE WSS2.email = WU.user_email)";
  			}
  		}

  		$joins = array(
  			"FROM {$wpdb->prefix}users WU",
  			"LEFT JOIN {$wpdb->prefix}comments WC ON WC.user_id = WU.ID",
  			"LEFT JOIN {$wpdb->prefix}usermeta WUM ON WUM.user_id = WU.ID AND WUM.meta_key = 'wp_user_level'",
  			"LEFT JOIN {$wpdb->prefix}usermeta WUMD ON WUMD.user_id = WU.ID AND WUMD.meta_key = '_IUD_deltime'"
  		);

  		if (is_plugin_active('wp-last-login/wp-last-login.php')) {
  			//we use wp-last-login plugin
  			$joins[] = "LEFT JOIN {$wpdb->prefix}usermeta WUM2 ON WUM2.user_id = WU.ID AND WUM2.meta_key = 'wp-last-login'";
  		} else {
  			//we will use own data
  			$joins[] = "LEFT JOIN {$wpdb->prefix}usermeta WUM2 ON WUM2.user_id = WU.ID AND WUM2.meta_key = 'last_login_gtm'";
  		}

  		//Classipress case last-login
  		$joins[] = "LEFT JOIN {$wpdb->prefix}usermeta WUM21 ON WUM21.user_id = WU.ID AND WUM21.meta_key = 'last_login'";

  		if (!empty($conditions)) {
  			$conditions_sec2[] = implode( $_POST['flagsCND'] == 'add' ? ' OR ' : ' AND ', $conditions);
      }

	  	//first action - comments published
      $query = "
        SELECT SQL_CALC_FOUND_ROWS SUM(WC.comment_approved = 1) as approved, SUM(WC.comment_approved = 'spam') as spam,
          WU.ID, WU.user_login as login, WU.user_email as mail, WU.user_url as url, WU.user_registered as dt_reg, WU.display_name as name,
		 		  WUM.meta_value as USL, WUM2.meta_value as last_login, WUM21.meta_value as last_login_classipress, WUMD.meta_value as removetime
			" . implode(" ", $joins) . "
          WHERE (" . 	implode( ') AND (', $conditions_sec2)	. ")
     			GROUP BY WU.ID, WU.user_login, WU.user_email, WU.user_url, WU.user_registered, WU.display_name, WUM.meta_value, WUM2.meta_value "
			. (!empty($havings) ? ' HAVING ' . implode(' AND ', $havings) : '');

  		switch ($_POST['sort_order']) {
  		case 'logindate':
  			$sort_order = 'WUM21.meta_value DESC, WUM2.meta_value DESC';
  			break;
  		case 'name':
  			$sort_order = 'WU.display_name';
  			break;
      case 'mail':
        $sort_order = 'WU.user_email';
        break;
  		case 'regdate':
  			$sort_order = 'WU.user_registered';
  			break;
  		case 'spam':
  			$sort_order = 'SUM(WC.comment_approved = \'spam\') DESC, WU.user_login';
  			break;
  		case 'userlevel':
  			$sort_order = 'WUM.meta_value DESC, WU.user_login';
  			break;
  		case 'comments':
  			$sort_order = 'SUM(WC.comment_approved = 1) DESC, WU.user_login';
  			break;
  		case 'posts':
  		default:
  			$sort_order = 'WU.user_login';
  		}
  		$query .= " ORDER BY $sort_order";

  		//limit section
  		$query .= $_POST['max_size_output'] == 'all' ? ' ' : ' LIMIT ' . ($_POST['max_size_output'] + 0);

      $rows = $wpdb->get_results($query, ARRAY_A);
	   	$total = $wpdb->get_var("SELECT FOUND_ROWS();");

      $user_list = array();
      if (!empty($rows)) {
        foreach($rows as $k => $UR) {
          $UR['recs'] = 0;
          $user_list[$UR['ID']] = $UR;
        }
      }

		  //clean up with registration lifetime ctiteria + check user norecs criteria + count publish posts
      $query = "
        SELECT COUNT(WP.ID) as recs, WU.ID
        FROM $wpdb->posts WP
        LEFT JOIN $wpdb->users WU ON WP.post_author = WU.ID
        WHERE 1 " . (empty($_POST['f_daysleft']) ? '' : "AND WU.user_registered < '$tmStr' ") . "
	       	AND NOT WP.post_type in ('attachment', 'revision') AND post_status = 'publish'
			  GROUP BY WU.ID
			  HAVING COUNT(WP.ID) > 0";

      $rows = $wpdb->get_results($query, ARRAY_A);

      if (!empty($rows)) {
        foreach($rows as $k => $UR) {
          $id = $UR['ID'];
          if (isset($user_list[$id])) $user_list[$id]['recs'] = $UR['recs'];
        }
      }

	  	//user's list output
      echo '<div class="section-title">' . __('Users list') . '</div>';
      if (empty($user_list)) {
        echo __('<p><b>No users are found.</b></p>');
      } else {
	   		$this->t_user_list($user_list, $total);
      }

      break;
    }

?>
</form>
</div>

<div class="sub-page" id="IUD_page_2">
<?php
	if (!empty($_POST['op']) && $_POST['op'] == 'misc') {
		//save and store options
		if ($_POST['informPeriod'] < 0) $_POST['informPeriod'] = 0;
		$_POST['informPeriod'] = intval($_POST['informPeriod'] + 0);

		if ($_POST['confirmPeriod'] <= 0) $_POST['confirmPeriod'] = 1;

		if ($_POST['informUsersNumber'] < 0) $_POST['informUsersNumber'] = 0;
		$_POST['informUsersNumber'] = intval($_POST['informUsersNumber'] + 0);

		$flags = array('informME', 'informUsers');

		foreach ($flags as $flag) {
			if (!isset($_POST[$flag]))
				$_POST[$flag] = 0;
		}
		//save $OP['last-inform']
		$OP = $_POST;
		unset($OP['sbm'], $OP['op']);

		self::save_settings($OP);
	}

	$OP = self::read_settings();
?>

	<form method="POST" action="">
	<input type="hidden" name="op" value="misc" />
	<input type="hidden" name="last-inform" value="<?php echo $OP['last-inform'];?>" />
	<p>
		There are miscellaneous options to drive plugin. No risks to delete users here.
	</p>
	<table cellspacing=5 border=0 cellpadding=0>
	<tr><th width=40></th><th align="left"></tr>
	<tr><td align="center">
			<input id="flag_inform_me" type="checkbox" name="informME" value="1" <?php echo empty($OP['informME']) ? '' : 'checked' ?> />
		</td>
		<td>
			<label for="flag_inform_me"><?php echo  __('Inform me about number of inactive users by email.') ?></label>
		</td>
	</tr>
	<tr style="display: <?php echo  empty($OP['informME']) ? 'none' : 'table-row' ?>">
		<td>&nbsp;</td>
		<td>
		<?php echo __('Send report every')?> <input id="informPeriod" size="2" maxlength="4" type="text" name="informPeriod" value="<?php echo $OP['informPeriod']?>" /> <?php echo __('day(s)')?>
		<?php echo __('when inactive user number will be at least')?> <input id="informUsersNumber" size="2" maxlength="4" type="text" name="informUsersNumber" value="<?php echo $OP['informUsersNumber']?>" />.<br/>
		<?php echo __('I will use this email'). ' : <b>'
		. get_option('admin_email', '<a href="' . admin_url('options-general.php') . '">SETUP email value here</a>')
		. '</b>.<br />';?>
		<?php echo __('Last report was sent')?> : <?php echo empty($OP['last-inform']) ? __('never') : date('d/M/Y H:i', $OP['last-inform']) . ' GMT' ?>.
		</td>
	</tr>
	<tr><td align="center">
			<input id="flag_inform_users" type="checkbox" name="informUsers" value="1" <?php echo empty($OP['informUsers']) ? '' : 'checked' ?> />
		</td>
		<td>
			<label for="flag_inform_users"><?php echo  __('Email before delete.') ?></label>
		</td>
	</tr>
	<tr style="display: <?php echo empty($OP['informUsers']) ? 'none' : 'table-row' ?>">
		<td>&nbsp;</td>
		<td><p>
		<?php echo __('I will send emails to users instead of instant account deleting. Mails will contain link to confirm user activity. ')
		. __('Users with non-confirmed accounts will be deleted after specified period of time.');
		?></p>
		<p>
		<?=__('Confirmation period')?>:
		<input id="confirmPeriod" size="2" maxlength="4" type="text" name="confirmPeriod" value="<?php echo $OP['confirmPeriod']?>" /> <?php echo __('day(s)')?>.
		</p>
		<p>
		<?=__('Letter of confirmation template')?>:<br />
		<textarea style="width: 80%" rows="10" name="confirmLetter"><?=htmlspecialchars($OP['confirmLetter'])?></textarea><br />
		<?=__('Template variables:')?>
		<pre>
:sitename - current domain sitename,
:confirmPeriod - confirmation period value,
:link - user-dependent link to prevent account deletion.</pre>
		</p>

		</td>
	</tr>
	<tr><td colspan="2"><input class="button-primary" name="sbm" type="submit" size="4" value="<?php echo __('Save')?>" /></td></tr>
	</table>

	</form>
</div>

<div class="sub-page" id="IUD_page_3">
	<p>
		<b>Version: <?php echo  self::actual_version?><br />
		<?php echo __('Developer')?>: <a href="http://shra.ru" rel="nofollow" target="_blank" >Korol Yuriy aka SHRA</a><br />
		<?php echo __('Plugin page')?>: <a href="https://wordpress.org/plugins/inactive-user-deleter/" rel="nofollow" target="_blank" >wordpress.org/plugins/inactive-user-deleter</a><br />
	</p>
<?php
	if (self::status != 'production') {
		if ($_POST['op'] == 'generate') {
			$this->create_arb_user($_POST['N'] + 0);
		}
?>
	<p>
		<form method="post" >
		<input type="hidden" name="op" value="generate" />
		Dummies Number: <input type="text" name="N" value="500" />	<input type="submit" name="op" value="generate" />
		</form>
	</p>
<?php
	}
?>
	<p>
		<img src="<?=substr(dirname(__FILE__), strlen($_SERVER['DOCUMENT_ROOT'])) . '/yurbanator.jpg' ?>" /><br />
		<?php echo __('Enjoy, this plugin is free to use.<br /> But you can support author for futher development (actually, for some beer and nuts).')?>
		<form action="https://www.paypal.com/cgi-bin/webscr" method="post" target="_top">
		<input type="hidden" name="cmd" value="_s-xclick">
		<input type="hidden" name="hosted_button_id" value="G4SDSLWJUHGNU">
		<input type="image" src="https://www.paypalobjects.com/en_US/RU/i/btn/btn_donateCC_LG.gif" border="0" name="submit" alt="PayPal - The safer, easier way to pay online!">
		<img alt="" border="0" src="https://www.paypalobjects.com/ru_RU/i/scr/pixel.gif" width="1" height="1">
		</form>
	</p>

</div>

</div>

<script>
jQuery(function() {
	jQuery('nav#IUD_pager div').click(function (){
		jQuery('nav#IUD_pager div').removeClass('active');
		jQuery(this).addClass('active');
		var pageID = jQuery(this).attr('data-page');
		jQuery('.sub-page').hide();
		jQuery('#' + pageID).show();
	});

	jQuery('nav#IUD_pager <?php echo (!empty($_POST['op']) && $_POST['op'] == 'misc') ? '#misc-button' : 'div:first-child' ?>').trigger('click');
  // Handler for .ready() called.
});

</script>
<?php
	}

	/* outputs user filters */
	public function t_user_filter() {
?>
<input type="hidden" name="op" value="search_users" />
<table >
<tr><td colspan="2">
	<div class="section-title"><?=__('Flags')?></div>
	<hr width=50% align="left"/>
	<?=_('Flags behaviuor. Add to list if ')?>
	<select name="flagsCND">
		<option value="intersept" <?php echo !empty($_POST['flagsCND']) && $_POST['flagsCND'] == 'intersept' ? selected : '' ?> ><?=__('... all conditions are true : AND CASE')?></option>
		<option value="add" <?php echo !empty($_POST['flagsCND']) && $_POST['flagsCND'] == 'add' ? 'selected' : '' ?> ><?=__('... any conditions are true : OR CASE')?></option>
	</select>
	</td>
</tr>
<tr><td colspan="2">
	<?=_('User has ...')?>
	</td>
</tr>
<tr>
	<td align="center" width=250>
		<label for="flag_approve_nomatter">
			<input id="flag_approve_nomatter" type="radio" name="f_approve" value="0" <?php echo empty($_POST['f_approve']) ? 'checked' : '' ?> />
			<?=__('No matter')?></label>
		<label for="flag_approve_no">
			<input id="flag_approve_no" type="radio" name="f_approve" value="no" <?php echo $_POST['f_approve'] === 'no' ? 'checked' : '' ?> />
			<?=__('No')?></label>
		<label for="flag_approve_yes">
			<input id="flag_approve_yes" type="radio" name="f_approve" value="yes" <?php echo $_POST['f_approve'] == 'yes' ? 'checked' : '' ?> />
			<?=__('Yes')?></label>
	</td>
	<td>
		<?php echo __('... approved comments.')?>
	</td>
</tr>
<tr>
<?php
	if (!isset($_POST['has_spam'])) $_POST['has_spam'] = 'yes';
?>

	<td align="center">
		<label for="flag_has_spam_nomatter">
			<input id="flag_has_spam_nomatter" type="radio" name="has_spam" value="0" <?php echo empty($_POST['has_spam']) ? 'checked' : '' ?> />
		<?=__('No matter')?></label>
		<label for="flag_has_spam_no">
			<input id="flag_has_spam_no" type="radio" name="has_spam" value="no" <?php echo $_POST['has_spam'] === 'no' ? 'checked' : '' ?> />
		<?=__('No')?></label>
		<label for="flag_has_spam_yes">
			<input id="flag_has_spam_yes" type="radio" name="has_spam" value="yes" <?php echo $_POST['has_spam'] === 'yes' ? 'checked' : '' ?> />
		<?=__('Yes')?></label>
	</td>
	<td>
		<?php echo __('... spam comments.')?>
	</td>
</tr>
<tr>
	<td align="center" valign="top">
		<label for="flag_has_recs_nomatter">
			<input id="flag_has_recs_nomatter" type="radio" name="has_recs" value="0" <?php echo empty($_POST['has_recs']) ? 'checked' : '' ?> />
		<?=__('No matter')?></label>
		<label for="flag_has_recs_no">
			<input id="flag_has_recs_no" type="radio" name="has_recs" value="no" <?php echo $_POST['has_recs'] === 'no' ? 'checked' : '' ?> />
		<?=__('No')?></label>
		<label for="flag_has_recs_yes">
			<input id="flag_has_recs_yes" type="radio" name="has_recs" value="yes" <?php echo $_POST['has_recs'] === 'yes' ? 'checked' : '' ?> />
		<?=__('Yes')?></label>
	</td>
	<td>
		<?php echo __('... (!Achtung) records or posts.')?><br />
		<small><?php echo __('I don`t pay respect to attachments and revisions, and consider only published articles.'); ?></small>
	</td>
</tr>
<tr valign="top">
	<td align="center">
		<label for="flag_userlog_in_nomatter">
			<input id="flag_userlog_in_nomatter" type="radio" name="f_usereverlogin" value="0" <?php echo empty($_POST['f_usereverlogin']) ? 'checked' : '' ?> />
			<?=__('No matter')?></label>
		<label for="flag_userlog_in_no">
			<input id="flag_userlog_in_no" type="radio" name="f_usereverlogin" value="no" <?php echo $_POST['f_usereverlogin'] === 'no' ? 'checked' : '' ?> />
			<?=__('No')?></label>
		<label for="flag_userlog_in_yes">
			<input id="flag_userlog_in_yes" type="radio" name="f_usereverlogin" value="yes" <?php echo $_POST['f_usereverlogin'] === 'yes' ? 'checked' : '' ?> />
			<?=__('Yes')?></label>
	</td>
	<td>
		<?php echo __('... known date log-in.')?> <br />
		<small><?php echo __('This flag adds users with known log-in date to list. Log in date isn`t native WP variable. So it will be collected while this module is activated or will be used <a href="https://wordpress.org/plugins/wp-last-login/" target="_blank">WP Last Login</a> plugin data or Classipress usermeta data.')?></small>
	</td>
</tr>
<tr valign="top">
<!--	<td align="center">
		&nbsp;
		<input id="flag_daysleft" style="text-align: center;" type="checkbox" name="f_daysleft" value="yes" <?php echo empty($_POST['f_daysleft']) ? '' : 'checked' ?> />
	</td>-->
	<td colspan="2">
		<div class="section-title"><?=__('Filters')?></div>
		<hr width=50% align="left"/>
		<label for="flag_daysleft"><?php echo __('User was created') ?>
		<select name="f_daysleft">
<?php
	if (!isset($_POST['f_daysleft'])) $_POST['f_daysleft'] = 1;
?>
			<option value="1" <?=!empty($_POST['f_daysleft'])  ? 'selected' : ''?>><?=__('more')?></option>
			<option value="0" <?=empty($_POST['f_daysleft']) ? 'selected' : ''?>><?=__('less')?></option>
		</select> <?=__('then')?>
		<input type="text" size="4" name="daysleft" value="<?php echo isset($_POST['daysleft']) ? intval($_POST['daysleft']) : 7 ?>" />
		<?php echo __('days ago. Set number of days.')?></label><br />
		<small><?php echo __('User need a time to begin commenting, subscribing, posting... Check to show recently registered user.')?></small>
	</td>
</tr>

<tr valign="top">
  <td colspan="2">
    <hr width=50% align="left"/>
    <label for="f_lastlogin"><?php echo __('Last time when user was logged-in is more then') ?>
    <select name="f_lastlogin">
      <option value="0">-- no filter --</option>
<?php
  $columns = array(15, 30, 60, 90, 180, 360, 720);

  foreach($columns as $v) {
    print '<option value="' . $v . '" ' . ($_POST['f_lastlogin'] == $v ? 'selected' : '') . '>' . $v . '</option>';
  }
?>

    </select> <?php echo __('days ago.') ?><br />
    <small><?php echo __('User was active, but long time ago. Probably it\'s time to remove him from database?')?></small>
  </td>
</tr>

<?php
	if ($this->ss2_active):
?>
<tr><td colspan="2">
  <hr width=50% align="left"/>
  </td>
</tr>
<tr valign="top">
	<td align="center">
		<label for="flag_s2_scriber_no">
			<input id="flag_s2_scriber_no" type="radio" name="has_SS2" value="0" <?php echo empty($_POST['has_SS2']) ? 'checked' : '' ?> /> No</label>
		<label for="flag_s2_scriber_yes">
			<input id="flag_s2_scriber_yes" type="radio" name="has_SS2" value="1" <?php echo empty($_POST['has_SS2']) ? '' : 'checked' ?> /> Yes</label>
	</td>
	<td>
		<?php echo __('User is SS2 subscriber.')?><br />
		<small><?=('Detect those, who has active subscriptions made by <a href="https://wordpress.org/plugins/subscribe2/" target="_blank">Subscribe2</a> plugin.');?></small>
	</td>
</tr>
<?php endif; ?>
<tr><td colspan="2">
  <hr width=50% align="left"/>
	<label for="user_level"><?php echo __('User level ')?></label>
	<select name="user_level_eq">
<?php
	$columns = array('>=', '<=');
	foreach($columns as $v) {
		print '<option value="' . $v . '" ' . ($_POST['user_level_eq'] == $v ? 'selected' : '') . '>' . $v . '</option>';
	}
?>
	</select>
	<input id="user_level" size="2" maxlength="2" type="text" name="user_level" value="<?php
		echo isset($_POST['user_level']) ?  $_POST['user_level'] + 0 : 0;?>" />
	<br /><small><?php echo  __('User level == 10 is admin, 0 is nobody.')?></small></td>
</tr>
<tr>
	<td align="left" colspan="2">
		<div class="section-title"><?=__('Formatting')?></div>
		<hr width=50% align="left"/>
		<label for="sort_order"><?php echo  __('Max size output')?></label>
		<select id="max_size_output" name="max_size_output" />
<?php
	$columns = array('150', '300', '500', '1000', '5000', 'all');

	foreach($columns as $v) {
		print '<option value="' . $v . '" ' . ($_POST['max_size_output'] == $v ? 'selected' : '') . '>' . $v . '</option>';
	}
?>
		</select> <?php echo __('recs.')?><br />
		<small><?php echo  __('PHP allows you sent only'). ' ' . ini_get('max_input_vars') . ' ' . __('input vars.')?></small>
	</td>
</tr>
<tr>
	<td align="left" colspan="2">
		<label for="sort_order"><?php echo  __('Sort by column')?></label>
		<select id="sort_order" name="sort_order" />
<?php
	$columns = array(
		'login' => 'user login',
    'mail' => 'user email',
		'logindate' => 'last log-in',
		'regdate' => 'register date',
		'name' => 'name',
		'userlevel' => 'userlevel',
		'spam' => 'spam',
		'comments' => 'comments');
	foreach($columns as $k => $v) {
		print '<option value="' . $k . '" ' . ($_POST['sort_order'] == $k ? 'selected' : '') . '>' . $v . '</option>';
	}
?>
		</select>
	</td>
</tr>
<tr><td colspan="2"><input class="button-primary" type="submit" size="4" value="<?php echo __('Search')?>" /></td></tr>
</table>
<a name="outputs"></a>

<?php
	}

	/* output user_list */
	public function t_user_list($user_list, $total) {

?>
	<p><b><?php echo  count($user_list) ?> <?php
		echo __('record(s) are shown.');
		if ($total > count($user_list)) {
			echo ' ' . $total . ' ' . __('are found total.');
    }
?></b></p>
	<hr><?php echo  __('Check this list') ?>.
	<input type="button" value="<?php echo  __('Mark all') ?>" onclick="IUD_markALL(this.form['f_users[]']);" />
	<input type="button" value="<?php echo  __('Unmark all') ?>" onclick="IUD_unmarkALL(this.form['f_users[]']);" />
	<?php echo  __('When everything is ready') ?> -
	<input type="button" class="button-secondary-red" value="<?php echo  __('Delete all marked users') ?>" onclick="
			if (confirm('Yes, I really want to delete all marked users.')) {
				this.form.op.value='delete';
				this.form.submit();
			}
		"/>
	<table cellpadding="3"><tr>
		<th>No.</th>
		<th><?php echo  __('Mark') ?></th>
		<th class="clickable" width="150" align="left" onclick="jQuery('#sort_order').val('login'); jQuery('#inactive-user-deleter-form').submit(); "><?php echo  __('Login') ?></th>
    <th class="clickable" align="left" onclick="jQuery('#sort_order').val('mail'); jQuery('#inactive-user-deleter-form').submit(); "><?php echo  __('Email') ?></th>
    <th class="clickable" align="left" onclick="jQuery('#sort_order').val('name'); jQuery('#inactive-user-deleter-form').submit(); "><?php echo  __('Name') ?></th>
		<th class="clickable" onclick="jQuery('#sort_order').val('userlevel'); jQuery('#inactive-user-deleter-form').submit(); "><?php echo  __('User level') ?></th>
		<th class="clickable" width="120" onclick="jQuery('#sort_order').val('regdate'); jQuery('#inactive-user-deleter-form').submit(); "><?php echo  __('Reg date') ?></th>
		<th class="clickable" width="120" onclick="jQuery('#sort_order').val('logindate'); jQuery('#inactive-user-deleter-form').submit(); "><?php echo  __('Last log-in') ?></th>
		<th><?php echo  __('Published posts') ?></th>
		<th class="clickable" onclick="jQuery('#sort_order').val('spam'); jQuery('#inactive-user-deleter-form').submit(); "><?php echo  __('Spam comments') ?></th>
		<th class="clickable" onclick="jQuery('#sort_order').val('comments'); jQuery('#inactive-user-deleter-form').submit(); "><?php echo  __('Approved comments') ?></th></tr>
<?php
      $i = 0;
			$stroked = 0;

      foreach($user_list as $UR) {
        $i++;
        $class = $i % 2 ? 'odd' : 'even';
        echo "<tr align=\"center\" class=\"$class\" ><td>$i.</td><td>";

				$login = (empty($UR['url']) ? $UR['login'] : "<a href=\"$UR[url]\" target=\"_blank\">$UR[login]</a>");
				if (!empty($UR['removetime'])) {
					$login = '<s>' . $login . '</s> *';
					//to remove checkbox
					$UR['ID'] = 1;
					$stroked ++;
				}

				if ($UR['USL'] >= 10 || $UR['ID'] == 1) {
					echo "-";
				} else {
					echo "<input type=\"checkbox\" name=\"f_users[]\" value=\"$UR[ID]\"/ "
                . (isset($_POST['f_users']) && in_array($UR['ID'], $_POST['f_users']) ? 'checked' : '')
                . ">";
				}

				//last_login_classipress date preferable
				$last_login = $UR['last_login_classipress'] ? strtotime($UR['last_login_classipress']) : $UR['last_login'];

				echo "</td>\n<td align=\"left\">{$login}</td>"
          . "<td align=\"left\">$UR[mail]</td><td align=\"left\">$UR[name]</td>"
					. "</td><td>" . ($UR['USL'] ? $UR['USL'] : '-') . "</td><td>"
					. date('d M Y', strtotime($UR['dt_reg'])) . "</td>"
					. '<td>' . ($last_login ? date('d M Y', $last_login) : '?') . "</td>"
					. '<td>' . ($UR['recs'] ? $UR['recs'] : '-')
					. "</td><td>"
					. ($UR['spam'] ? $UR['spam'] : '-')
					. "</td><td>"
					. ($UR['approved'] ? $UR['approved'] : '-')
					. "</td></tr>\n";
            }
?>
	</table>
<?php
  	if ($stroked) {
  		echo '<p>* - striked through logins - user is informed (by email) about deletion and marked to delete soon.<p>';
  	}
?>
	<script>
		function IUD_markALL(f_elm) {
			if (f_elm.length > 0) {
				for(i=0; i<f_elm.length; i++)
					f_elm[i].checked = true;
			} else f_elm.checked = true;
		}
		function IUD_unmarkALL(f_elm) {
			if (f_elm.length > 0) {
				for(i=0; i<f_elm.length; i++)
					f_elm[i].checked = false;
			} else f_elm.checked = false;
		}
	</script>
  <?php
    readfile(dirname(__FILE__) . '/user-table.css');
	}

	public function add_action_links($links, $file) {
		if (strpos($file, 'inactive-user-deleter.php' ) === false ) return $links;
		$mylinks = array(
			'<a href="' . admin_url( 'users.php?page=' . $file ) . '">' . __('Settings') . '</a>',
		);

		return array_merge( $links, $mylinks );
	}

	/* fast user generation routine - only for test purposes */
	private function create_arb_user($n = 100) {
		while ($n-- > 0) {
			$asr = rand(1000000, 10000000);
			wp_create_user('usr_' . $asr, 'pass_'. $asr, $asr . '@mail.ru');
		}
	}

	static function save_settings($OP) {
		update_option('UsrInDeleter_settings', $OP);
	}

	static function read_settings() {
		return array_merge(self::default_settings(), get_option('UsrInDeleter_settings', array()));
	}

	static function default_settings() {
		return array(
			'informME' => 0,
			'informUsersNumber' => 50,
			'informPeriod' => 7, //days
			'informCOND' => 'OR',
			'last-inform' => 0,
			//since v1.2
			'ver' => 1.0,
			//since v1.31
			'informUsers' => 0,
			'confirmPeriod' => 7,
			'confirmLetter' => '<p>Dear subscriber!</p>
<p>Please confirm your interest to continue be part of :sitename community.<br />
Your account will be deleted in :confirmPeriod days. To prevent deletion, please visit out website using next link:<br />
:link</p>
<p>
---<br />
Sincerely yours, webmaster of :sitename.</p>'
		);
	}
}
}

$inactive_user_deleter_obj = new InactiveUserDeleter();
